@@ -10,6 +10,7 @@ from llcsciencesdk.exceptions import (
     ApiTokenError,
 )
 from llcsciencesdk.helpers import json_response_to_df
+from llcsciencesdk.parameter_mapping import update_legacy_parameter
 from llcsciencesdk.urls import make_urls, ApiUrls
 
 
@@ -46,6 +47,18 @@ class ScienceSdk:
 
         return response.json()
 
+    def post_request(self, url, data):
+        if not self.auth_token:
+            raise ApiTokenError
+
+        response = requests.post(
+            url,
+            headers={"Authorization": f"Bearer {self.auth_token}"},
+            json=data
+        )
+
+        return response.json()
+
     def get_model_input_fast_track_json(
         self, site_design_configuration_id: int
     ) -> dict:
@@ -96,6 +109,12 @@ class ScienceSdk:
         url = self.api_urls.GET_PLANTING_DESIGN_LIST
         return self.get_request(url)
 
+    def update_remote_sensing_dashboard_status(
+            self,planting_design_id: int, status: int
+    ) -> dict:
+        url = f"{self.api_urls.UPDATE_REMOSTE_SENSING_DASHBOARD_STATUS}{planting_design_id}"
+        return self.post_request(url, {"status": status})
+
     # START LEGACY METHODS --------------------
     # TODO: remove once all fast track instances use new SDK methods
     def get_model_inputs_as_df(self, config_option: int, legacy_parameters=False):
@@ -147,11 +166,8 @@ class ScienceSdk:
             raise ApiTokenError
 
         list_of_runs = ",".join(map(str, model_runs))
-        url = self.api_urls.GET_OLD_MODEL_INPUT_URL + f"={list_of_runs}",
-        if legacy_parameters:
-            url = url[0] + "&legacy_parameters"
         data = requests.get(
-            url[0],
+            self.api_urls.GET_OLD_MODEL_INPUT_URL + f"={list_of_runs}",
             headers={"Authorization": f"Bearer {self.auth_token}"},
         )
 
@@ -167,6 +183,11 @@ class ScienceSdk:
         df_species_info = pd.json_normalize(species_info)
         df_model_info = pd.json_normalize(model_info)
 
+        if legacy_parameters:
+            for i, row in df_parameter_data.iterrows():
+                df_parameter_data.at[i, 'ParameterName'] = update_legacy_parameter(row["ParameterName"])
+            for i, row in df_parameter_info.iterrows():
+                df_parameter_info.at[i, 'ParameterName'] = update_legacy_parameter(row["ParameterName"])
         return (
             df_sites_info,
             df_parameter_data,
